@@ -16,7 +16,7 @@ def decode(payload: str) -> bytes:
         # By running `future-fstrings-show`, it adds `unicode_literals` that
         # redefines some classes so the default behaviour changes
         def native_str_to_bytes(s, encoding=None):
-            from future.types import newbytes
+            from future.types import newbytes  # pylint: disable=import-outside-toplevel
             return newbytes(s, encoding=encoding)
         payload = native_str_to_bytes(payload, encoding='utf-8')
 
